FontCx

Struct FontCx 

pub struct FontCx {
    pub context: FontContext,
    /* private fields */
}
A font database and cache, used for font family resolution and text layout.

This resource is a wrapper around parley::FontContext.

Fields

context: FontContext

A font database/cache (wrapper around a Fontique Collection and SourceCache).

Implementations

Source

impl FontCx

pub fn get_family<'a>(&'a mut self, source: &'a FontSource) -> Option<&'a str>

Get the family name associated with a FontSource.

If the FontSource is a Handle, returns None. The family name can be found by using the handle to look up the Font asset instead.

pub fn set_generic_family( &mut self, generic: GenericFamily, family_name: &str, ) -> Result<(), TextError>

Sets the fallback font for a given generic family.

In most cases, these methods do not need to called manually, as parley::fontique will automatically select appropriate default fonts based on available system fonts.

Note that the parley/system feature must be enabled to allow automatic system font discovery.

These methods will return an error if the provided family name does not already exist in the font collection.

pub fn set_serif_family(&mut self, family_name: &str) -> Result<(), TextError>

Sets the serif generic family mapping.

pub fn set_sans_serif_family( &mut self, family_name: &str, ) -> Result<(), TextError>

Sets the sans-serif generic family mapping.

pub fn set_cursive_family(&mut self, family_name: &str) -> Result<(), TextError>

Sets the cursive generic family mapping.

pub fn set_fantasy_family(&mut self, family_name: &str) -> Result<(), TextError>

Sets the fantasy generic family mapping.

pub fn set_monospace_family( &mut self, family_name: &str, ) -> Result<(), TextError>

Sets the monospace generic family mapping.

pub fn set_system_ui_family( &mut self, family_name: &str, ) -> Result<(), TextError>

Sets the system-ui generic family mapping.

pub fn set_ui_serif_family( &mut self, family_name: &str, ) -> Result<(), TextError>

Sets the ui-serif generic family mapping.

pub fn set_ui_sans_serif_family( &mut self, family_name: &str, ) -> Result<(), TextError>

Sets the ui-sans-serif generic family mapping.

pub fn set_ui_monospace_family( &mut self, family_name: &str, ) -> Result<(), TextError>

Sets the ui-monospace generic family mapping.

pub fn set_ui_rounded_family( &mut self, family_name: &str, ) -> Result<(), TextError>

Sets the ui-rounded generic family mapping.

pub fn set_emoji_family(&mut self, family_name: &str) -> Result<(), TextError>

Sets the emoji generic family mapping.

pub fn set_math_family(&mut self, family_name: &str) -> Result<(), TextError>

Sets the math generic family mapping.

pub fn set_fang_song_family( &mut self, family_name: &str, ) -> Result<(), TextError>

Sets the fangsong generic family mapping.

pub fn restore_generic_families(&mut self)

Call after clearing the font Collection to restore the generic family mappings.