FontWeight

Struct FontWeight 

pub struct FontWeight(pub u16);
How thick or bold the strokes of a font appear.

Valid font weights range from 1 to 1000, inclusive. Weights above 1000 are clamped to 1000. A weight of 0 is treated as FontWeight::DEFAULT.

Legacy names from when most fonts weren’t variable fonts are included as const values, but are misleading if used in documentation and examples, as valid weights for variable fonts are all of the numbers from 1-1000, and not all fonts which are not variable fonts have those weights supplied. If you use a custom font that supplies only specific weights, that will be documented where you purchased the font.

<https://developer.mozilla.org/en-US/docs/Web/CSS/Reference/Properties/font-weight>

Tuple Fields

0: u16

Implementations

Source

impl FontWeight

pub const THIN: FontWeight

Weight 100.

pub const EXTRA_LIGHT: FontWeight

Weight 200.

pub const LIGHT: FontWeight

Weight 300.

pub const NORMAL: FontWeight

Weight 400.

pub const MEDIUM: FontWeight

Weight 500.

pub const SEMIBOLD: FontWeight

Weight 600.

pub const BOLD: FontWeight

Weight 700.

pub const EXTRA_BOLD: FontWeight

Weight 800

pub const BLACK: FontWeight

Weight 900.

pub const EXTRA_BLACK: FontWeight

Weight 950.

pub const DEFAULT: FontWeight = Self::NORMAL

The default font weight.

pub const fn clamp(self) -> Self

Clamp the weight value to between 1 and 1000. Values of 0 are mapped to Weight::DEFAULT.